@@ -15,22 +15,27 @@ from texta_mlp.document import Document
 from texta_mlp.entity_mapper import EntityMapper
 from texta_mlp.exceptions import LanguageNotSupported
 
-
+# Languages supported by default.
 DEFAULT_LANG_CODES = ("et", "ru", "en")
-USE_GPU_FOR_STANZA = True
 
+# URLs for default Entity Mapper data sources.
 ENTITY_MAPPER_DATA_URLS = (
     "https://git.texta.ee/texta/texta-resources/-/raw/master/entity_mapper/addresses.json",
-    "https://git.texta.ee/texta/texta-resources/-/raw/master/entity_mapper/companies.json"
+    "https://git.texta.ee/texta/texta-resources/-/raw/master/entity_mapper/companies.json",
+    "https://git.texta.ee/texta/texta-resources/-/raw/master/entity_mapper/currencies.json"
 )
 
+# URLs for Concatenator data sources.
 CONCATENATOR_DATA_FILES = (
     "https://git.texta.ee/texta/texta-resources/-/raw/master/concatenator/months.txt",
     "https://git.texta.ee/texta/texta-resources/-/raw/master/concatenator/not_entities.txt",
     "https://git.texta.ee/texta/texta-resources/-/raw/master/concatenator/space_between_not_ok.txt",
 )
 
+# Location of the resource dir where models are downloaded
 DEFAULT_RESOURCE_DIR = os.path.join(os.getcwd(), "data")
+
+# List of all analyzers supported by MLP
 SUPPORTED_ANALYZERS = (
     "lemmas",
     "pos_tags",
@@ -41,16 +46,14 @@ SUPPORTED_ANALYZERS = (
     "phone_strict",
     "entities",
     "namemail",
-    "bounded"
+    "bounded",
+    "currency_sum"
 )
 
-# Here we can optimize memory imprint of Stanza by limiting the number of processors.
-# If language not defined here, default will be used.
-STANZA_PROCESSOR_OPTS = {
-    "default": "tokenize,pos,lemma,ner",
-    # no NER for Estonian yet
-    "et": "tokenize,pos,lemma"
-}
+# Here we define languages with NER support to avoid Stanza trying to load them for languages without NER support.
+# This significantly increases performance for languages without NER.
+# https://stanfordnlp.github.io/stanza/available_models.html#available-ner-models
+STANZA_NER_SUPPORT = ("ar", "zh", "nl", "en", "fr", "de", "ru", "es", "uk")
 
 
 class MLP:
@@ -62,7 +65,7 @@ class MLP:
             use_default_language_code=True,
             resource_dir: str = DEFAULT_RESOURCE_DIR,
             logging_level="error",
-            use_gpu=USE_GPU_FOR_STANZA
+            use_gpu=True
     ):
         self.supported_langs = language_codes
         self.logger = logging.getLogger()
@@ -251,12 +254,13 @@ class MLP:
     @staticmethod
     def _get_stanza_processors(lang):
         """
-        Returns processor options based on language.
+        Returns processor options based on language and NER support in Stanza.
         """
-        if lang not in STANZA_PROCESSOR_OPTS:
-            return STANZA_PROCESSOR_OPTS["default"]
+        print(lang)
+        if lang in STANZA_NER_SUPPORT:
+            return "tokenize,pos,lemma,ner"
         else:
-            return STANZA_PROCESSOR_OPTS[lang]
+            return "tokenize,pos,lemma"
 
 
     def process(self, raw_text: str, analyzers: list = ["all"], lang=None):
